## Quantile modelling of Birth-weight data suing VGAM ##

## Change this:
# setwd("~/AUT/collabThomas/twoParPaper-formatted/")

source("uninormalMod.R")
source("normalQlink.R")
library("VGAM")
library("VGAMextra")

## Reading in the data set.
qrdata <- read.csv("bweight.csv")
qrdata$Black <- as.factor(qrdata$Black)
qrdata$Married <- as.factor(qrdata$Married)
qrdata$Boy <- as.factor(qrdata$Boy)
qrdata$MomSmoke <- as.factor(qrdata$MomSmoke)
#qrdata$CigsPerDay <- as.factor(qrdata$CigsPerDay)
qrdata$MomEdLevel <- as.factor(qrdata$MomEdLevel)
qrdata$Weight <- as.numeric(qrdata$Weight)
qrdata$MomWtGain <- as.numeric(qrdata$MomWtGain) 
qrdata$Visit <- as.numeric(qrdata$Visit)

## Quantiles of interest
mytau <- c(0.10, 0.25, 0.50, 0.75, 0.90)

## Model 1 - log sigma is intercept only. ,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,
## Identical effect of covariates across the 'mytau'
fit.qr.mod <- vglm(Q.reg(Weight, pvector = mytau) ~Black + Married + Boy +
                     Visit + MomEdLevel + MomSmoke +
                     CigsPerDay + MomAge + MomAge * MomAge +
                     MomWtGain + MomWtGain*MomWtGain,
                   family = uninormalMod(lmean = uninormalQlink(p = mytau),
                                         zero = "sd",
                  #                      zero = NULL,
                                         p.vector = mytau),
                   trace = TRUE, data = qrdata)
constraints(fit.qr.mod)
( mymat <- coef(fit.qr.mod, mat = TRUE) )

# Plot quantiles vs. beta_hat
MomWtGainCoef <- mymat[12, c(1, 3, 5, 7)]
plot(mytau, MomWtGainCoef, pch = 21, col = "blue", 
     xlab = "quantiles", lwd = 4, ylim = c(0, 12), xlim = c(0, 1))
lines(mytau, MomWtGainCoef)



## Model 2 - zero = NULL (coeffs make sense?) ,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,
## Identical effect of covariates across the 'mytau'
fit.qr.mod <- vglm(Q.reg(Weight, pvector = mytau) ~Black + Married + Boy +
                     Visit + MomEdLevel + MomSmoke +
                     CigsPerDay + MomAge + MomAge * MomAge +
                     MomWtGain + MomWtGain*MomWtGain,
                   family = uninormalMod(lmean = uninormalQlink(p = mytau),
                   #                      zero = "sd",
                                         zero = NULL,
                                         p.vector = mytau),
                   trace = TRUE, data = qrdata)
constraints(fit.qr.mod)
( mymat <- coef(fit.qr.mod, mat = TRUE) )

# Plot quantiles vs. beta_hat
MomWtGainCoef <- mymat[12, c(1, 3, 5, 7)]
plot(mytau, MomWtGainCoef, pch = 21, col = "blue", 
     xlab = "quantiles", lwd = 4, ylim = c(0, 12), xlim = c(0, 1))
lines(mytau, MomWtGainCoef)
