

negbinomial.control <- function(save.weights = TRUE, ...) {
  list(save.weights = save.weights)
}



nbcanlink.old <- function(theta,
                          size = NULL,
                          wrt.eta = NULL,
                          bvalue = NULL,
                          inverse = FALSE, deriv = 0,
                          short = TRUE, tag = FALSE) {
  if (is.character(theta)) {
    string <- if (short)
      paste("nbcanlink(", theta, ")", sep = "") else {
        theta <- as.char.expression(theta)
        paste("log(", theta, " / (", theta, " + size))", sep = "")
      }
    if (tag)
      string <- paste("Nbcanlink:", string)
    return(string)
  }
  
  
  
  kmatrix <- size
  theta <- cbind(theta)
  kmatrix <- cbind(kmatrix)
  if (ncol(kmatrix) != ncol(theta))
    stop("arguments 'theta' and 'size' do not have ",
         "an equal number of cols")
  if (nrow(kmatrix) != nrow(theta))
    stop("arguments 'theta' and 'size' do not have ",
         "an equal number of rows")
  
  
  if (deriv > 0) {
    if (!(wrt.eta %in% 1:2))
      stop("argument 'wrt.eta' should be 1 or 2")
  }
  
  
  if (!inverse && length(bvalue))
    theta[theta <= 0.0] <- bvalue
  
  if (inverse) {
    switch(deriv+1, {
      ans <- (kmatrix / expm1(-theta))
      if (is.matrix(ans))
        dimnames(ans) <- NULL else
          names(ans) <- NULL
        ans
    },
    
    if (wrt.eta == 1) (theta * (theta + kmatrix)) / kmatrix else
      -(theta + kmatrix),
    
    if (wrt.eta == 1)
      (2 * theta + kmatrix) * theta * (theta + kmatrix) / kmatrix^2 else
        theta + kmatrix)
  } else {
    ans <-
      switch(deriv+1,
             log(theta / (theta + kmatrix)) ,
             
             if (wrt.eta == 1) kmatrix / (theta * (theta + kmatrix)) else
               -1 / (theta + kmatrix),
             
             if (wrt.eta == 1)
               (2 * theta + kmatrix) *
               (-kmatrix) / (theta * (theta + kmatrix))^2 else
                 1 / (theta + kmatrix)^2)
    
    if (is.matrix(ans))
      dimnames(ans) <- NULL else
        names(ans) <- NULL
      ans
  }
}



negbinomial.old <-
  function(lmu = "loge", lsize = "loge",
           imu = NULL,   isize = NULL,
           probs.y = 0.75,
           nsimEIM = 250, cutoff.prob = 0.995,  # Maxiter = 5000,
           max.qnbinom = 1000,
           max.chunk.MB = 20,  # max.memory = Inf is allowed
           deviance.arg = FALSE, imethod = 1,
           gsize = exp((-4):4),
           parallel = FALSE,
           ishrinkage = 0.95, zero = -2) {
    
    
    
    
    
    
    
    
    
    alternate.derivs <- FALSE  # 20130823; added for 'nbcanlink'
    
    
    if (!is.logical( deviance.arg ) || length( deviance.arg ) != 1)
      stop("argument 'deviance.arg' must be TRUE or FALSE")
    
    
    
    lmuuu <- as.list(substitute(lmu))
    emuuu <- link2list(lmuuu)
    lmuuu <- attr(emuuu, "function.name")
    
    imuuu <- imu
    
    lsize <- as.list(substitute(lsize))
    esize <- link2list(lsize)
    lsize <- attr(esize, "function.name")
    
    
    if (length(imuuu) && !is.Numeric(imuuu, positive = TRUE))
      stop("bad input for argument 'imu'")
    if (length(isize) && !is.Numeric(isize, positive = TRUE))
      stop("bad input for argument 'isize'")
    
    if (!is.Numeric(cutoff.prob, length.arg = 1) ||
        cutoff.prob < 0.95 ||
        cutoff.prob >= 1)
      stop("range error in the argument 'cutoff.prob'")
    if (!is.Numeric(imethod, length.arg = 1,
                    integer.valued = TRUE, positive = TRUE) ||
        imethod > 3)
      stop("argument 'imethod' must be 1 or 2 or 3")
    if (!is.Numeric(ishrinkage, length.arg = 1) ||
        ishrinkage < 0 ||
        ishrinkage > 1)
      stop("bad input for argument 'ishrinkage'")
    
    if (!is.Numeric(nsimEIM, length.arg = 1, integer.valued = TRUE))
      stop("bad input for argument 'nsimEIM'")
    if (nsimEIM <= 10)
      warning("argument 'nsimEIM' should be an integer ",
              "greater than 10, say")
    
    
    if (is.logical( parallel ) && parallel  && length(zero))
      stop("need to set 'zero = NULL' when parallel = TRUE")
    
    
    
    ans <- 
      new("vglmff",
          
          
          
          
          blurb = c("Negative-binomial distribution\n\n",
                    "Links:    ",
                    namesof("mu",   lmuuu, earg = emuuu), ", ",
                    namesof("size", lsize, earg = esize), "\n",
                    "Mean:     mu\n",
                    "Variance: mu * (1 + mu / size) for NB-2"),
          
          constraints = eval(substitute(expression({
            
            
            
            
            constraints <- cm.VGAM(matrix(1, M, 1), x = x,
                                   bool = .parallel , 
                                   constraints = constraints)
            
            dotzero <- .zero
            M1 <- 2
            eval(negzero.expression.VGAM)
          }), list( .parallel = parallel, .zero = zero ))),
          
          
          
          infos = eval(substitute(function(...) {
            list(M1    = 2,
                 Q1    = 1,
                 multipleResponses = TRUE,
                 lmu   = .lmuuu ,
                 lsize = .lsize ,
                 zero  = .zero )
          }, list( .zero = zero, .lsize = lsize, .lmuuu = lmuuu ))),
          
          
          
          initialize = eval(substitute(expression({
            M1 <- 2
            
            temp5 <- w.y.check(w = w, y = y,
                               Is.integer.y = TRUE,
                               ncol.w.max = Inf,
                               ncol.y.max = Inf,
                               out.wy = TRUE,
                               colsyperw = 1, maximize = TRUE)
            w <- temp5$w
            y <- temp5$y
            
            
            assign("CQO.FastAlgorithm",
                   ( .lmuuu == "loge") && ( .lsize == "loge"),
                   envir = VGAMenv)
            
            if (any(function.name == c("cqo", "cao")) &&
                is.Numeric( .zero , length.arg = 1) &&
                .zero != -2)
              stop("argument zero = -2 is required")
            
            
            if (any(y < 0))
              stop("negative values not allowed for the 'negbinomial' family")
            if (any(round(y) != y))
              stop("integer-values only allowed for the 'negbinomial' family")
            if (ncol(w) > ncol(y))
              stop("number of columns of prior-'weights' is greater than ",
                   "the number of responses")
            
            M <- M1 * ncol(y) 
            NOS <- ncoly <- ncol(y)  # Number of species
            predictors.names <-
              c(namesof(if (NOS == 1) "mu"   else paste("mu",   1:NOS, sep = ""),
                        .lmuuu , earg = .emuuu , tag = FALSE),
                namesof(if (NOS == 1) "size" else paste("size", 1:NOS, sep = ""),
                        .lsize , earg = .esize , tag = FALSE))
            predictors.names <- predictors.names[interleave.VGAM(M, M = M1)]
            
            
            if (is.numeric( .mu.init ))
              MU.INIT <- matrix( .mu.init , nrow(y), ncol(y), byrow = TRUE)
            
            
            if (!length(etastart)) {
              mu.init <- y
              for (jay in 1:ncol(y)) {
                use.this <- if ( .imethod == 1) {
                  weighted.mean(y[, jay], w[, jay]) + 1/16
                } else if ( .imethod == 3) {
                  c(quantile(y[, jay], probs = .probs.y ) + 1/16)
                } else {
                  median(y[, jay]) + 1/16
                }
                
                if (is.numeric( .mu.init )) {
                  mu.init[, jay] <- MU.INIT[, jay]
                } else {
                  medabsres <- median(abs(y[, jay] - use.this)) + 1/32
                  allowfun <- function(z, maxtol = 1) sign(z) * pmin(abs(z), maxtol)
                  mu.init[, jay] <- use.this + (1 - .ishrinkage ) *
                    allowfun(y[, jay] - use.this, maxtol = medabsres)
                  
                  mu.init[, jay] <- abs(mu.init[, jay]) + 1 / 1024
                }
              }  # of for (jay)
              
              if ( is.Numeric( .k.init )) {
                kay.init <- matrix( .k.init , nrow = n, ncol = NOS, byrow = TRUE)
              } else {
                negbinomial.Loglikfun <- function(kmat, y, x, w, extraargs) {
                  mu <- extraargs
                  sum(c(w) * dnbinom(x = y, mu = mu, size = kmat, log = TRUE))
                }
                k.grid <- .gsize
                kay.init <- matrix(0, nrow = n, ncol = NOS)
                for (spp. in 1:NOS) {
                  kay.init[, spp.] <- grid.search(k.grid,
                                                  objfun = negbinomial.Loglikfun,
                                                  y = y[, spp.], x = x, w = w[, spp.],
                                                  extraargs = mu.init[, spp.])
                }
              }
              
              newemu <- .emuuu
              if ( .lmuuu == "nbcanlink.old") {
                newemu$size <- kay.init
              }
              
              
              
              
              etastart <-
                cbind(theta2eta(mu.init , link = .lmuuu , earg = newemu ),
                      theta2eta(kay.init, link = .lsize , earg = .esize ))
              etastart <-
                etastart[, interleave.VGAM(M, M = M1), drop = FALSE]
            }
          }), list( .lmuuu = lmuuu, .lsize = lsize,
                    .emuuu = emuuu, .esize = esize,
                    .mu.init = imu, .gsize = gsize,
                    .deviance.arg = deviance.arg,
                    .k.init = isize, .probs.y = probs.y,
                    .ishrinkage = ishrinkage, .nsimEIM = nsimEIM,
                    .zero = zero, .imethod = imethod ))),
          
          linkinv = eval(substitute(function(eta, extra = NULL) {
            M1 <- 2
            NOS <- ncol(eta) / M1
            eta.k <- eta[, M1 * (1:NOS) , drop = FALSE]
            kmat <- eta2theta(eta.k, .lsize , earg = .esize )
            
            
            
            
            newemu <- .emuuu
            if ( .lmuuu == "nbcanlink.old") {
              newemu$size <- kmat
            }
            
            
            
            eta2theta(eta[, M1 * (1:NOS) - 1, drop = FALSE], .lmuuu ,
                      earg = newemu)
          }, list( .lmuuu = lmuuu, .lsize = lsize,
                   .emuuu = emuuu, .esize = esize))),
          
          last = eval(substitute(expression({
            if (exists("CQO.FastAlgorithm", envir = VGAMenv))
              rm("CQO.FastAlgorithm", envir = VGAMenv)
            
            
            save.weights <- control$save.weights <- !all(ind2)
            
            
            temp0303 <- c(rep( .lmuuu , length = NOS),
                          rep( .lsize , length = NOS))
            names(temp0303) =
              c(if (NOS == 1) "mu"   else paste("mu",   1:NOS, sep = ""),
                if (NOS == 1) "size" else paste("size", 1:NOS, sep = ""))
            temp0303 <- temp0303[interleave.VGAM(M, M = 2)]
            misc$link <- temp0303 # Already named
            
            misc$earg <- vector("list", M)
            names(misc$earg) <- names(misc$link)
            for (ii in 1:NOS) {
              misc$earg[[M1*ii-1]] <- newemu
              misc$earg[[M1*ii  ]] <- .esize
            }
            
            misc$max.chunk.MB <- .max.chunk.MB
            misc$cutoff.prob <- .cutoff.prob
            misc$imethod <- .imethod 
            misc$nsimEIM <- .nsimEIM
            misc$expected <- TRUE
            misc$ishrinkage <- .ishrinkage
            misc$multipleResponses <- TRUE
          }), list( .lmuuu = lmuuu, .lsize = lsize,
                    .emuuu = emuuu, .esize = esize,
                    .cutoff.prob = cutoff.prob,  # .min.size = min.size,
                    .max.chunk.MB = max.chunk.MB,
                    .nsimEIM = nsimEIM,
                    .ishrinkage = ishrinkage,
                    .imethod = imethod ))),
          
          linkfun = eval(substitute(function(mu, extra = NULL) {
            M1 <- 2
            
            newemu <- .emuuu
            
            eta.temp <- theta2eta(mu, .lmuuu , earg = newemu)
            eta.kayy <- theta2eta(if (is.numeric( .isize )) .isize else 1.0,
                                  .lsize , earg = .esize )
            eta.kayy <- 0 * eta.temp + eta.kayy  # Right dimension now.
            
            
            
            
            
            if ( .lmuuu == "nbcanlink.old") {
              newemu$size <- eta2theta(eta.kayy, .lsize , earg = .esize )
            }
            
            
            
            eta.temp <- cbind(eta.temp, eta.kayy)
            eta.temp[, interleave.VGAM(ncol(eta.temp), M = M1), drop = FALSE]
          }, list( .lmuuu = lmuuu, .lsize = lsize,
                   .emuuu = emuuu, .esize = esize,
                   .isize = isize ))),
          
          loglikelihood = eval(substitute(
            function(mu, y, w, residuals = FALSE, eta,
                     extra = NULL,
                     summation = TRUE) {
              M1 <- 2
              NOS <- ncol(eta) / M1
              
              eta.k <- eta[, M1*(1:NOS), drop = FALSE]
              
              if ( FALSE && .lsize == "loge") {
                bigval <- 68
                eta.k <- ifelse(eta.k >  bigval,  bigval, eta.k)
                eta.k <- ifelse(eta.k < -bigval, -bigval, eta.k)
              }
              kmat <- eta2theta(eta.k, .lsize , earg = .esize )
              
              
              
              newemu <- .emuuu
              if ( .lmuuu == "nbcanlink.old") {
                newemu$size <- kmat
              }
              
              
              
              
              
              if (residuals) {
                stop("loglikelihood residuals not implemented yet")
              } else {
                ll.elts <- c(w) * dnbinom(x = y, mu = mu, size = kmat, log = TRUE)
                if (summation) {
                  sum(ll.elts)
                } else {
                  ll.elts
                }
              }
            }, list( .lsize = lsize,
                     .lmuuu = lmuuu, .emuuu = emuuu, .esize = esize))),
          
          vfamily = c("negbinomial"),
          
          
          
          simslot = eval(substitute(
            function(object, nsim) {
              
              pwts <- if (length(pwts <- object@prior.weights) > 0)
                pwts else weights(object, type = "prior")
              if (any(pwts != 1)) 
                warning("ignoring prior weights")
              eta <- predict(object)
              muuuu <- cbind(eta2theta(eta[, c(TRUE, FALSE)], .lmuuu , .emuuu ))
              eta.k <- cbind(eta2theta(eta[, c(FALSE, TRUE)], .lsize , .esize ))
              rnbinom(nsim * length(muuuu), mu = muuuu, size = eta.k)
            }, list( .lmuuu = lmuuu, .lsize = lsize,
                     .emuuu = emuuu, .esize = esize ))),
          
          
          
          
          
          deriv = eval(substitute(expression({
            
            
            
            
            if ( iter == 1 && .deviance.arg ) {
              if (control$criterion != "coefficients" &&
                  control$half.step)
                warning("Argument 'criterion' should be 'coefficients' ",
                        "or 'half.step' should be 'FALSE' when ",
                        "'deviance.arg = TRUE'")
              
              
              
              
              
              low.index <- ifelse(names(constraints)[1] == "(Intercept)", 2, 1)
              if (low.index <= length(constraints))
                for (iii in low.index:length(constraints)) {
                  conmat <- constraints[[iii]]
                  if (any(conmat[c(FALSE, TRUE), ] != 0))
                    stop("argument 'deviance.arg' should only be TRUE for NB-2 models; ",
                         "non-zero elements detected for the 'size' parameter." )
                }
            }
            
            
            
            
            
            
            
            M1 <- 2
            NOS <- ncol(eta) / M1
            M <- ncol(eta)
            eta.k <- eta[, M1*(1:NOS)  , drop = FALSE]
            if (FALSE && .lsize == "loge") {
              bigval <- 68
              eta.k <- ifelse(eta.k >  bigval,  bigval, eta.k)
              eta.k <- ifelse(eta.k < -bigval, -bigval, eta.k)
            }
            kmat <- eta2theta(eta.k, .lsize , earg = .esize )
            
            
            
            
            newemu <- .emuuu
            if ( .lmuuu == "nbcanlink.old") {
              newemu$size <- kmat
            }
            
            
            
            dl.dmu <- y / mu - (y + kmat) / (mu + kmat)
            dl.dk  <- digamma(y + kmat) - digamma(kmat) -
              (y - mu) / (mu + kmat) + log(kmat / (kmat + mu))
            
            if ( .lmuuu == "nbcanlink.old")
              newemu$wrt.eta <- 1
            dmu.deta <- dtheta.deta(mu, .lmuuu , earg = newemu)  # eta1
            
            if ( .lmuuu == "nbcanlink.old")
              newemu$wrt.eta <- 2
            dk.deta1 <- dtheta.deta(mu, .lmuuu , earg = newemu)  # eta2
            
            dk.deta2 <- dtheta.deta(kmat, .lsize , earg = .esize )
            
            
            
            myderiv <- c(w) * cbind(dl.dmu * dmu.deta,
                                    dl.dk  * dk.deta2)
            
            
            if ( .lmuuu == "nbcanlink.old") {
              if ( iter%% 2 == 0) {
                myderiv[, 1:NOS] <- dl.dk  * dk.deta1
              } else {
              }
            }
            
            
            myderiv <- myderiv[, interleave.VGAM(M, M = M1)]
            
            
            if ( .alternate.derivs || ( .lmuuu == "nbcanlink.old")) {  # 20130823 added
            }
            
            
            myderiv
          }), list( .lmuuu = lmuuu, .lsize = lsize,
                    .alternate.derivs = alternate.derivs,
                    .deviance.arg = deviance.arg,
                    .emuuu = emuuu, .esize = esize))),
          
          
          
          weight = eval(substitute(expression({
            wz <- matrix(as.numeric(NA), n, M)
            
            
            max.qnbinom <- .max.qnbinom
            max.chunk.MB <- .max.chunk.MB
            
            
            EIM.NB.special2 <- function(mu, size, y.max = NULL,
                                        cutoff.prob = 0.995,
                                        intercept.only = FALSE) {
              
              
              
              if (intercept.only) {
                mu <- mu[1]
                size <- size[1]
              }
              
              if (!is.numeric(y.max)) {
                y.max <- max(qnbinom(p = cutoff.prob, mu = mu, size = size)) + 2
              }
              
              Y.mat <- if (intercept.only) 0:y.max else
                matrix(0:y.max, length(mu), y.max+1, byrow = TRUE)
              trigg.term <- if (intercept.only) {
                dnbinom(Y.mat, size = size, mu = mu) %*% trigamma(Y.mat + size)
              } else {
                rowSums(dnbinom(Y.mat, size = size, mu = mu) *
                          trigamma(Y.mat + size))
              }
              ned2l.dk2 <- trigamma(size) - 1 / size + 1 / (size + mu) - trigg.term
              ned2l.dk2
            }  # end of EIM.NB.special2()
            
            
            
            ind2 <- matrix(FALSE, n, NOS)  # Used for SFS
            for (jay in 1:NOS) {
              Q.maxs <- qnbinom(p = .cutoff.prob , mu = mu[, jay],
                                size = kmat[, jay])
              ind1 <- if (max.chunk.MB > 0) (Q.maxs < max.qnbinom) else FALSE
              if ((NN <- sum(ind1)) > 0) {
                Object.Size <- NN * 8 * max(Q.maxs) / (2^20)  # Mb; 8 bytes/double
                n.chunks <- if (intercept.only) 1 else
                  max(1, ceiling( Object.Size / max.chunk.MB))
                chunk.rows <- ceiling(NN / n.chunks)
                ind2[, jay] <- ind1  # Save this
                wind2 <- which(ind1)
                
                
                upr.ptr <- 0
                lwr.ptr <- upr.ptr + 1
                while (lwr.ptr <= NN) {
                  upr.ptr <- min(upr.ptr + chunk.rows, NN)
                  sind2 <- wind2[lwr.ptr:upr.ptr]
                  wz[sind2, M1*jay] <-
                    EIM.NB.special2(mu          =   mu[sind2, jay],
                                    size        = kmat[sind2, jay],
                                    y.max = max(Q.maxs[sind2]),
                                    cutoff.prob = .cutoff.prob ,
                                    intercept.only = intercept.only) *
                    (dk.deta2[sind2, jay])^2
                  lwr.ptr <- upr.ptr + 1
                }  # while
                
              }
            }  # end of for (jay in 1:NOS)
            
            
            
            
            
            
            for (jay in 1:NOS) {
              run.varcov <- 0
              ii.TF <- !ind2[, jay]  # Not assigned above
              if (any(ii.TF)) {
                kkvec <- kmat[ii.TF, jay]
                muvec <-   mu[ii.TF, jay]
                for (ii in 1:( .nsimEIM )) {
                  ysim <- rnbinom(sum(ii.TF), mu = muvec, size = kkvec)
                  dl.dk <- digamma(ysim + kkvec) - digamma(kkvec) -
                    (ysim + kkvec) / (muvec + kkvec) +
                    1 + log(kkvec / (kkvec + muvec))
                  run.varcov <- run.varcov + dl.dk^2
                }  # end of for loop
                
                run.varcov <- c(run.varcov / .nsimEIM )
                ned2l.dk2 <- if (intercept.only) mean(run.varcov) else run.varcov
                
                wz[ii.TF, M1*jay] <- ned2l.dk2 * (dk.deta2[ii.TF, jay])^2
              }
            }
            
            
            save.weights <- !all(ind2)
            
            
            ned2l.dmu2 <- 1 / mu - 1 / (mu + kmat)
            wz[, M1*(1:NOS) - 1] <- ned2l.dmu2 * dmu.deta^2
            
            
            
            if ( FALSE && .lmuuu == "nbcanlink.old") {
              if ( iter %% 2 == 0) {
                
                wz[, M1*(1:NOS) - 1] <- ned2l.dk2 * dk.deta1^2
                
                
              } else {
              }
            }
            
            
            
            
            w.wz.merge(w = w, wz = wz, n = n, M = M, ndepy = NOS)
          }), list( .cutoff.prob = cutoff.prob,
                    .max.qnbinom = max.qnbinom,
                    .max.chunk.MB = max.chunk.MB,
                    .lmuuu = lmuuu,
                    .nsimEIM = nsimEIM ))))
    
    
    
    
    if (deviance.arg) {
      ans@deviance <- eval(substitute(
        function(mu, y, w, residuals = FALSE, eta, extra = NULL,
                 summation = TRUE) {
          
          
          
          
          
          
          M1 <- 2
          NOS <- ncol(eta) / M1
          eta.k <- eta[, M1 * (1:NOS) , drop = FALSE]
          kmat <- eta2theta(eta.k, .lsize , earg = .esize )
          
          if (residuals) {
            stop("this part of the function has not been written yet.")
          } else {
            size <- kmat
            dev.elts <- 2 * c(w) *
              (y * log(pmax(1, y) / mu) -
                 (y + size) * log((y + size) / (mu + size)))
            if (summation) {
              sum(dev.elts)
            } else {
              dev.elts
            }
          }
        }, list( .lsize = lsize, .esize = esize,
                 .lmuuu = lmuuu, .emuuu = emuuu )))
      
      
      
      
      
    }
    
    
    
    
    
    ans
  }  # End of negbinomial()

